@@ -1515,7 +1515,7 @@ class Unit(UnitBase, abstract=True):
                     # we send. For example, this can happen when a large file is
                     # read in chunks and the pick unit is used to select only the
                     # first few of these.
-                    self.log_info(F'cannot send to next unit: {E}')
+                    self.log_debug(F'cannot send to next unit: {E}')
                 break
 
         try:
@@ -1743,7 +1743,7 @@ class Unit(UnitBase, abstract=True):
         results are used to construct an instance of the unit, this object is consequently returned.
         """
         argp = cls.argparser(**keywords)
-        args = argp.parse_args(args)
+        args = argp.parse_args_with_nesting(args)
 
         try:
             unit = autoinvoke(cls, args.__dict__)
